**Example 1: 修改单元名称**



Input: 

```
tccli iecp ModifyEdgeUnitCloudApi --cli-unfold-argument  \
    --EdgeUnitId 100022 \
    --Name wwww11
```

Output: 
```
{
    "Response": {
        "RequestId": "2f1f5564-b038-4c8c-b965-f91c0a394f88"
    }
}
```

